@@ -50,19 +50,16 @@ class NavigatorBar;
 class KOCheckableProxyModel;
 class AkonadiCollectionView;
 
-namespace CalendarSupport
-{
+namespace CalendarSupport {
 class CalPrinter;
 class IncidenceViewer;
 }
 
-namespace IncidenceEditorNG
-{
+namespace IncidenceEditorNG {
 class IncidenceDialog;
 }
 
-namespace Akonadi
-{
+namespace Akonadi {
 class History;
 class IncidenceChanger;
 class CalendarClipboard;
@@ -78,12 +75,17 @@ class CalendarViewExtension : public QWidget
 {
     Q_OBJECT
 public:
-    explicit CalendarViewExtension(QWidget *parent) : QWidget(parent) {}
+    explicit CalendarViewExtension(QWidget *parent) : QWidget(parent)
+    {
+    }
 
     class Factory
     {
     public:
-        virtual ~Factory() {}
+        virtual ~Factory()
+        {
+        }
+
         virtual CalendarViewExtension *create(QWidget *parent) = 0;
     };
 };
@@ -107,7 +109,7 @@ public:
       @param parent   parent window
     */
     explicit CalendarView(QWidget *parent = nullptr);
-    virtual ~CalendarView();
+    ~CalendarView() override;
 
     class CalendarViewVisitor : public KCalCore::Visitor
     {
@@ -138,6 +140,7 @@ public:
     {
         return mViewManager;
     }
+
     KODialogManager *dialogManager() const
     {
         return mDialogManager;
@@ -147,18 +150,22 @@ public:
     {
         return mRightFrame;
     }
+
     QWidget *leftFrame() const
     {
         return mLeftFrame;
     }
+
     NavigatorBar *navigatorBar() const
     {
         return mNavigatorBar;
     }
+
     DateNavigator *dateNavigator() const
     {
         return mDateNavigator;
     }
+
     // TODO_NG
     //IncidenceEditors::IncidenceEditor *editorDialog( const Akonadi::Item &item ) const;
     Akonadi::IncidenceChanger *incidenceChanger() const override
@@ -305,8 +312,7 @@ public Q_SLOTS:
                   const QString &description = QString(),
                   const QStringList &attachment = QStringList(),
                   const QStringList &attendees = QStringList(),
-                  const QStringList &attachmentMimetypes = QStringList(),
-                  bool inlineAttachment = false);
+                  const QStringList &attachmentMimetypes = QStringList(), bool inlineAttachment = false);
     void newFloatingEvent();
 
     /** Create a read-only viewer dialog for the supplied incidence.
@@ -393,11 +399,11 @@ public Q_SLOTS:
     /** create new todo with parent todo */
     void newSubTodo(const Akonadi::Collection &collection);
 
-    void newTodo(const QString &summary, const QString &description = QString(),
+    void newTodo(const QString &summary,
+                 const QString &description = QString(),
                  const QStringList &attachments = QStringList(),
                  const QStringList &attendees = QStringList(),
-                 const QStringList &attachmentMimetypes = QStringList(),
-                 bool inlineAttachment = false);
+                 const QStringList &attachmentMimetypes = QStringList(), bool inlineAttachment = false);
 
     void newJournal();
     void newJournal(const QDate &date);
@@ -440,26 +446,23 @@ public Q_SLOTS:
     void changeIncidenceDisplay(const Akonadi::Item &incidence,
                                 Akonadi::IncidenceChanger::ChangeType);
 
-    void slotCreateFinished(int changeId,
-                            const Akonadi::Item &item,
+    void slotCreateFinished(int changeId, const Akonadi::Item &item,
                             Akonadi::IncidenceChanger::ResultCode resultCode,
                             const QString &errorString);
 
-    void slotModifyFinished(int changeId,
-                            const Akonadi::Item &item,
+    void slotModifyFinished(int changeId, const Akonadi::Item &item,
                             Akonadi::IncidenceChanger::ResultCode resultCode,
                             const QString &errorString);
 
-    void slotDeleteFinished(int changeId,
-                            const QVector<Akonadi::Item::Id> &itemIdList,
+    void slotDeleteFinished(int changeId, const QVector<Akonadi::Item::Id> &itemIdList,
                             Akonadi::IncidenceChanger::ResultCode resultCode,
                             const QString &errorString);
 
     void startMultiModify(const QString &text);
     void endMultiModify();
 
-    void updateView(const QDate &start, const QDate &end,
-                    const QDate &preferredMonth, const bool updateTodos = true);
+    void updateView(const QDate &start, const QDate &end, const QDate &preferredMonth,
+                    const bool updateTodos = true);
     void updateView() override;
 
     void updateUnmanagedViews();
@@ -681,7 +684,8 @@ private:
 
     void createPrinter();
 
-    void dissociateOccurrence(const Akonadi::Item &incidence, const QDate &, bool futureOccurrences);
+    void dissociateOccurrence(const Akonadi::Item &incidence, const QDate &,
+                              bool futureOccurrences);
 
     /**
      * Returns the default collection.
@@ -731,7 +735,7 @@ private:
     KCalCore::CalFilter *mCurrentFilter = nullptr;
 
     // various housekeeping variables.
-    bool  mReadOnly; // flag indicating if calendar is read-only
+    bool mReadOnly;  // flag indicating if calendar is read-only
 
     Akonadi::Item mSelectedIncidence;
     QDate mSaveDate;
@@ -741,7 +745,6 @@ private:
     Akonadi::ITIPHandler *mITIPHandler = nullptr;
     QList<int> mMainSplitterSizes; // temp store for main splitter sizes while left frame is hidden
     bool mSplitterSizesValid;
-    bool mCreatingEnabled;
 
     Akonadi::CalendarClipboard *mCalendarClipboard = nullptr;
     KOCheckableProxyModel *mCheckableProxyModel = nullptr;
